@@ -17,7 +17,7 @@
 #endif
 
 // Current version of biorbd
-#define BIORBD_VERSION "1.3.1"
+#define BIORBD_VERSION "1.3.3"
 
 // Choice of linear algebra backend
 #define BIORBD_USE_EIGEN3_MATH
@@ -49,14 +49,14 @@ inline LINEAR_ALGEBRA_BACKEND currentLinearAlgebraBackend(){
 #endif
 
 // Choice of modules
+#define MODULE_KALMAN
 #define MODULE_ACTUATORS
 #define MODULE_MUSCLES
+/* #undef MODULE_STATIC_OPTIM */
 #define MODULE_VTP_FILES_READER
 
 // Define some skip if ones doesn't want to compile them
-/* #undef SKIP_KALMAN */
 /* #undef SKIP_ASSERT */
-#define SKIP_STATIC_OPTIM
 /* #undef SKIP_LONG_TESTS */
 
 #ifndef M_PI
